# Flatchr Connector
> Flatchr is a software company that offers recruitment and application management software for human resources.

🔗 https://www.flatchr.io/

| Actions |
| ------- |
| [**Push profile**](docs/push_profile.md) |